@@ -41,9 +41,9 @@ Ext.override(Ext.m3.gar.AddressFields, {
             if (this.hasStreetField() && (!this.isStreetEmpty() ||
                   (this.isStreetEmpty() && this.streetNameField.allowBlank))) {
                 if (this.hasHouseField() && !this.isHouseEmpty()) {
-                    if (this.isSteadSelected) {
+                    if (this.houseNumberField.getValue().indexOf('уч.') > -1) {
                         addressParts.push(
-                        'земельный участок ' + this.houseNumberField.getValue()
+                         'земельный участок ' + this.houseNumberField.getValue().substring(4)
                         );
                     }
                     else {
